<html>
  <head c:include="xml/header.html"></head>
  <body>
    <kr-app id="app" b:is_pwa="int(request.user_agent.is_mobile)" entrypoint="kirui.main.entrypoint">
      <kr-layout-sidebar n:b:class="{'isPwa': self.component_config.application.is_pwa}">
        <kr-sidebar-header c:include="xml/sidebar_header.html" />

        <kr-sidebar-nav c:include="xml/menu.html" />

        <kr-sidebar-main>
          <kr-form c:include="xml/form_data.html" />
        </kr-sidebar-main>
      </kr-layout-sidebar>
    </kr-app>
  </body>
</html>