<head>
    <meta charset="utf-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no" />
    <title>kirUI</title>

    <script type="text/javascript" b:src="djsamon.static('django_kirui/brython.min.js')"></script>
    <script type="text/javascript" b:src="djsamon.static('django_kirui/brython_stdlib.js')"></script>
    <script type="text/javascript" b:src="djsamon.static('django_kirui/tinymce/tinymce.min.js')"></script>
    <!-- script type="text/javascript" src="https://cdn.jsdelivr.net/npm/brython@3.9/brython.min.js"></script>
    <script type="text/javascript" src="https://cdn.jsdelivr.net/npm/brython@3.9/brython_stdlib.js"></script -->
    <!-- script type="text/javascript" src="https://cdnjs.cloudflare.com/ajax/libs/tinymce/5.0.10/tinymce.min.js"></script -->
    <script type="text/javascript" b:src="djsamon.static('jquery/js/jquery-3.6.0.min.js')"></script>

    <script type="text/javascript" b:src="djsamon.bundled_static('kirui/js/kirui.brython.js')"></script>
    <link rel="stylesheet" b:href="djsamon.bundled_static('bootstrap/scss/bootstrap.scss.css')" />
    <!-- script type="text/javascript" b:src="djsamon.static('django_kirui/kirui.brython.js')"></script>
    <link rel="stylesheet" b:href="djsamon.static('django_kirui/kirui.css')" / -->
    <link href="https://fonts.googleapis.com/css2?family=Material+Icons" rel="stylesheet" />
</head>